# Container Guts!

[![PyPI version](https://badge.fury.io/py/container-guts.svg)](https://badge.fury.io/py/container-guts)

Want to know the "guts" inside your container, or more specifically,
the executables on the PATH inside? 🤓

![docs/assets/img/guts-colors-small.png](docs/assets/img/guts-colors-small.png)

This is a library and set of GitHub actions to derive that!

## Usage

For client and GitHub Actions usage, see our ⭐️ [documentation](https://singularityhub.github.io/guts/) ⭐️

## TODO

- support for singularity and podman (if requested)
